-- 
-- Extra columns for jobhistory
-- 
ALTER TABLE jobhistory ADD COLUMN accounting_user TEXT;
ALTER TABLE jobhistory ADD COLUMN authorising_user TEXT;

-- 
-- Trigger for jobhistory to populate and maintain extra columns
-- from options.
-- 
-- NB: pykota database must be primed by running following command
-- from postgres account:
-- createlang plpgsql pykota
-- 
CREATE FUNCTION decode_options() RETURNS trigger AS '
BEGIN
  IF NEW.options IS NULL THEN
    NEW.accounting_user := NULL;
    NEW.authorising_user := NULL;
  ELSE
    NEW.accounting_user  := substring(NEW.options from
	                             ''cued-accounting-user=(\\\\S+)\\\\s*'');
    NEW.authorising_user := substring(NEW.options from
                                     ''cued-authorising-user=(\\\\S+)\\\\s*'');
  END IF;
  RETURN NEW;
END;
' LANGUAGE plpgsql;

CREATE TRIGGER decode_options 
  BEFORE INSERT OR UPDATE ON jobhistory
  FOR EACH ROW EXECUTE PROCEDURE decode_options();

