-- 
-- CUED extensions to pykota postgresql database
-- 

--
-- Create extra print quota database users
-- 
CREATE USER pykotaweb;

-- 
-- Now connect to the new database
-- 
\connect pykota

--
-- Create the authhistory table
--
CREATE TABLE authhistory(
	id 		SERIAL PRIMARY KEY NOT NULL,
	jobid 		TEXT NOT NULL,
	username	TEXT NOT NULL,
	printername	TEXT NOT NULL REFERENCES printers(printername),
	jobnumber	TEXT,
	remotehost 	TEXT,
	confirmed	BOOLEAN DEFAULT 'f',
	authdate	TIMESTAMP DEFAULT now()
	);
CREATE INDEX authhistory_username_ix ON authhistory (username);
CREATE INDEX authhistory_jobid_ix ON authhistory (jobid);
CREATE INDEX authhistory_jobnumber_ix ON authhistory (jobnumber);

REVOKE ALL on authhistory FROM public;
REVOKE ALL on authhistory_id_seq FROM public;

GRANT SELECT, INSERT, UPDATE, DELETE, REFERENCES 
   ON authhistory 
   TO pykotaadmin, pykotaweb;
GRANT SELECT, UPDATE ON authhistory_id_seq TO pykotaadmin, pykotaweb;
GRANT SELECT ON authhistory TO pykotauser;

-- 
-- Extra columns for payments
-- 
ALTER TABLE payments ADD COLUMN adminuser TEXT;
ALTER TABLE payments ADD COLUMN adminhost TEXT;
ALTER TABLE payments ADD COLUMN comment TEXT;
ALTER TABLE payments ADD COLUMN oldbalance FLOAT;

-- 
-- Extra columns for jobhistory
-- 
ALTER TABLE jobhistory ADD COLUMN accounting_user TEXT;
ALTER TABLE jobhistory ADD COLUMN authorising_user TEXT;

-- 
-- Trigger for jobhistory to populate and maintain extra columns
-- from options.
-- 
-- NB: pykota database must be primed by running following command
-- from postgres account:
-- createlang plpgsql pykota
-- 
CREATE FUNCTION decode_options() RETURNS trigger AS '
BEGIN
  IF NEW.options IS NULL THEN
    NEW.accounting_user := NULL;
    NEW.authorising_user := NULL;
  ELSE
    NEW.accounting_user  := substring(NEW.options from
	                             ''cued-accounting-user=(\\\\S+)\\\\s*'');
    NEW.authorising_user := substring(NEW.options from
                                     ''cued-authorising-user=(\\\\S+)\\\\s*'');
  END IF;
  RETURN NEW;
END;
' LANGUAGE plpgsql;

CREATE TRIGGER decode_options 
  BEFORE INSERT OR UPDATE ON jobhistory
  FOR EACH ROW EXECUTE PROCEDURE decode_options();

-- 
-- Extra permissions for pykotaweb
--  
GRANT SELECT, INSERT, UPDATE 
   ON users, payments
   TO pykotaweb;
GRANT SELECT, UPDATE ON users_id_seq, payments_id_seq TO pykotaweb;

GRANT SELECT ON jobhistory, printers TO pykotaweb;

-- EOF
